@@ -1268,8 +1268,8 @@ class OpenAssessmentBlock(MessageMixin,
             "parts": parts_list
         }
 
-        for key in kwargs:
-            event_data[key] = kwargs[key]
+        for key, value in kwargs.items():
+            event_data[key] = value
 
         self.runtime.publish(
             self, event_name,
@@ -1371,7 +1371,7 @@ class OpenAssessmentBlock(MessageMixin,
         # otherwise self.prompt would have json embedded in the string.
         try:
             prompt = {
-                "prompt_{}".format(prompt_i): self._clean_data(prompt.get("description", ""))
+                f"prompt_{prompt_i}": self._clean_data(prompt.get("description", ""))
                 for prompt_i, prompt in enumerate(json.loads(self.prompt))
             }
         except ValueError:
