@@ -79,7 +79,7 @@ NECESSITY_OPTIONS = [
 ]
 
 # Build editor options from AVAILABLE_EDITORS
-AVAILABLE_EDITOR_OPTIONS = AVAILABLE_EDITORS.keys()
+AVAILABLE_EDITOR_OPTIONS = set(AVAILABLE_EDITORS.keys())
 
 VALID_ASSESSMENT_TYPES = [
     'peer-assessment',
